WakingPipeDev

Struct WakingPipeDev 

pub struct WakingPipeDev {
    pub pipe: WakingPipe,
    pub medium: Medium,
    pub mtu: usize,
}
Wrapper around WakingPipe to implement smoltcp::phy::Device.

Like netcore::PipeDev except that it implements AsyncWakeDevice.

Fields

pipe: WakingPipe

End of a pipe that will be directly connected to the netstack, receiving packets to be sent and supplying packets to be received.

medium: Medium

The type of network frame the pipe will carry.

For our purposes, this will typically be Medium::Ip.

mtu: usize

The maximum packet size to be transmitted through the pipe.

The implementation does not check or limit the actual size of packets flowing through it, this field is just informational for smoltcp::phy::Device::capabilities.