pub struct Netstack<D> { /* private fields */ }Expand description
A userspace network stack.
This is a relatively thin shell around CoreStack to provide convenience runtime
features.
Implementations
Sourceimpl<D> Netstack<D>
impl<D> Netstack<D>
Sourcepub fn with_clock(dev: D, config: Config, clock: Clock) -> Self
pub fn with_clock(dev: D, config: Config, clock: Clock) -> Self
Construct a new netstack with the given device, configuration, and clock.
Sourcepub fn run_blocking(&mut self, poll_delay: Duration)where
D: Device,
pub fn run_blocking(&mut self, poll_delay: Duration)where
D: Device,
Run the netstack, driving the internal event loop to consume commands.
Runs forever, blocking the current thread.
poll_delay is the amount of time to sleep when we’re done with I/O and commands to
process: a smaller delay improves latency at the cost of CPU cycles spent polling.
Consider the async methods for an event-driven approach.
Sourcepub async fn run_with_sleep(&mut self, sleep: impl AsyncFn(Duration) + Clone)
pub async fn run_with_sleep(&mut self, sleep: impl AsyncFn(Duration) + Clone)
Run the netstack, driving the internal event loop to consume commands.
The sleep function is the runtime-specific sleep implementation. It has the
Clone bound for esoteric async type system reasons (the loop needs to call the
function multiple times, but it doesn’t want to reason about &impl AsyncFn). A
normal closure or async fn ref will satisfy the bound.